<?php

namespace Drupal\entity_reference_delete_check_paragraph_url\EventSubscriber;

use Drupal\entity_reference_delete_check\Event\DeleteCheckEntityUrlEvent;
use Drupal\paragraphs\ParagraphInterface;
use Exception;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * This event subscriber provides URLs to pages where a paragraph might be found.
 */
class ParagraphUrlProvider implements EventSubscriberInterface {

  public static function getSubscribedEvents(): array {
    return [
      DeleteCheckEntityUrlEvent::class => 'setUrl',
    ];
  }

  public function setUrl(DeleteCheckEntityUrlEvent $event): void {
    $entity = $event->entity;
    if (!$entity instanceof ParagraphInterface) {
      return;
    }
    while ($entity instanceof ParagraphInterface) {
      $entity = $entity->getParentEntity();
    }
    if (!$entity) {
      return;
    }
    try {
      $event->setUrl($entity->toUrl());
    } catch (Exception) {
      // can't do everything
    }
  }

}
